CuboidMaterial

Struct CuboidMaterial 

pub struct CuboidMaterial {
    pub color_mode: ColorMode,
    pub wireframe: u32,
    pub scalar_hue: ScalarHueOptions,
    pub emissive_gain: Vec3,
}
Shading options, constant for each draw call.

Fields

color_mode: ColorModewireframe: u32

Nonzero values imply that only cuboid edges will be shaded. VertexPullingRenderPlugin::edges must be true for this to take effect.

scalar_hue: ScalarHueOptionsemissive_gain: Vec3

An extra factor that multiplies a cuboid’s color when the “emissive” bit on MetaBits is set.