pub struct CuboidMaterialId(pub usize);Expand description
Denotes which CuboidMaterial to use when rendering
Cuboids.
When a material is modified, all entities with the corresponding
CuboidMaterialId will be affected.
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for CuboidMaterialId
impl Clone for CuboidMaterialId
Sourcefn clone(&self) -> CuboidMaterialId
fn clone(&self) -> CuboidMaterialId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Component for CuboidMaterialId
impl Component for CuboidMaterialId
Sourcetype Storage = TableStorage
type Storage = TableStorage
A marker type indicating the storage type used for this component.
This must be either
TableStorage or SparseStorage.impl Copy for CuboidMaterialId
impl Eq for CuboidMaterialId
Sourceimpl Hash for CuboidMaterialId
impl Hash for CuboidMaterialId
Sourceimpl PartialEq for CuboidMaterialId
impl PartialEq for CuboidMaterialId
impl StructuralPartialEq for CuboidMaterialId